<?php

/**
 * Name: RFG Tournaments (RFGT)
 * URI: http://10kyu.ru
 
 * Description: Класс позволяющий загружать и выводить данные
 *              о ближайших турнирах с сайта Российской федерации Го
 *              http://gofederation.ru/
 
 * Version: 1.0.0
 
 * Author: 2014 Михаил Пестречихин (Mikhail Pestrechikhin)
 * Author URI: http://mike.pestr.ru/
 
 * License: MIT
 */

class RFGT {
		
	// Путь к папке для кэширования данных относительно корня сайта.
	// К этой папке должен быть открыт доступ на запись (777).
	const CACHE_FOLDER = "/rfgt/cache/";
	
	const API_PATH = 'http://gofederation.ru/api/v1/tournaments';
	 
	private $data;
	
	public function Show($max_days = 30, $limit = 0) {
	
		self::LoadData($max_days, $limit);
		
		if ($this->data!='') {
		
			foreach($this->data as $d) {
				
				// Вывод информации о ближайших турнирах РФГ (можно менять HTML-разметку)
				echo "<div class='rfgt_date'>{$d['startDate']} - {$d['endDate']}</div>";
				echo "<div class='rfgt_title'><a href='{$d['url']}' target='_blank'>{$d['name']}</a></div>";
				echo "<div class='rfgt_place'>{$d['place']}</div>";
				// Конец вывода
				
				if ($limit>0 && ++$count>=$limit) 
					break;
			}
		}
		else {
			
			// Вывод сообщения об ошибке, если турниры не найдены, или не получилось загрузить данные.
			echo "<div class='rfgt_error'>Информация не найдена или не удалась загрузка модуля.</div>";
		}
		
	}		
	
	private function LoadData($max_days, $limit) {
	
		$params = 'start_ge='.date("d.m.Y").';sort=start;urls=full';
		
		if ($max_days>0)
		{
			$date_end = new DateTime(date("Y-m-d"));
			$date_end->add(new DateInterval('P'.$max_days.'D'));
			$params.=';start_le='.$date_end->format("d.m.Y");
		}
		
		$error_level = error_reporting();
		error_reporting(E_ERROR);

		$context = stream_context_create(array(
			'http' => array(
				'ignore_errors' => true
			)
		));
		
		$source = self::API_PATH.'?'.$params;
		$filename = $_SERVER['DOCUMENT_ROOT'].self::CACHE_FOLDER.$max_days."-".$limit;
		
		if (file_exists($filename))
		{
			$old_date = filemtime($filename);
			if (date("d.m.Y",$old_date)!=date("d.m.Y"))
				copy($source , $filename, $context);
		}
		else
			copy($source, $filename, $context);
		
		if ($data = file_get_contents($filename, false, $context)) {
			$this->data = json_decode($data,true);
			if ($this->data['result']=='OK')
				$this->data = $this->data['data'];
			else
				$this->data = '';
		}
		
		error_reporting($error_level);
			
	}
	
}
	
?>